(******************************************************************************
 * TAcIniFilles                                                               *
 ******************************************************************************)
unit AcIniFiles;

(******************************************************************************
 *                                                                            *
 ******************************************************************************)
interface

(******************************************************************************
 *                                                                            *
 ******************************************************************************)
uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs;

(******************************************************************************
 *                                                                            *
 ******************************************************************************)
type
  TACIniFiles = class(TComponent)
  private
    { Private declarations }
     F_Nome_File : String;
     txt         : TStringList; // Oggetto che contiene il file ".INI"
  protected
    { Protected declarations }
    function Completa_nome_sezione(nome:String):string;
    function cerca_sezione(nome:String):integer;
    function cerca_ident(Sezione,Ident:String):integer;
    function Corregge_Ident(nome: string):String;
    Procedure Tolgie_doppio_ident(Primo:Integer;Ident : String);
    
  public
    { Public declarations }
    Constructor Create(AOwner: TComponent); Override;
    Procedure WriteString(Section, Ident, Value: string);
    Function ReadString(Section, Ident, DefaultValue: string):String;
    Procedure WriteInteger(Section, Ident:String; Value: Integer);
    Function ReadInteger(Section, Ident:String; DefaultValue: Integer):Integer;

  published
    { Published declarations }
    Property FileName : String Read F_Nome_File Write F_Nome_File;

  end;

(******************************************************************************
 *                                                                            *
 ******************************************************************************)
implementation


(******************************************************************************
 *                                                                            *
 ******************************************************************************)
Constructor TACIniFiles.Create(AOwner: TComponent);
Begin
  Inherited;
  FileName := '';

End;

(******************************************************************************
 *                                                                            *
 ******************************************************************************)
function TACIniFiles.Completa_nome_sezione(nome:String):string;
begin
  Nome := Trim(Nome);
  if (nome='') then nome := '[]'
  else
  begin
    if (nome[1]<>'[') then Nome := '['+Nome;
    if (nome[Length(nome)]<>']') then Nome := Nome+']';
  end;
  Completa_nome_sezione := Nome;

end;

(******************************************************************************
 *                                                                            *
 ******************************************************************************)
function TACIniFiles.cerca_sezione(nome:String):integer;
var c1, c2 : integer;
begin
  c2 := -1;
  Nome := uppercase(Completa_nome_sezione(nome));
  for c1 := 0 to txt.count - 1 do
  begin
    if(uppercase(trim(txt[c1]))=nome) Then
    begin
      c2 := c1;
      break;
    end;
  end;
  cerca_sezione := c2;
end;

(******************************************************************************
 *                                                                            *
 ******************************************************************************)
function TACIniFiles.Corregge_Ident(nome: string):String;
var c1 : integer;
begin
  Nome := Trim(nome);
  for c1 := 1 to length(nome) do
  begin
    if (nome[c1]='=') then Nome[c1] := '_';
  end;
  Corregge_Ident := nome;
end;

(******************************************************************************
 *                                                                            *
 ******************************************************************************)
Procedure TACIniFiles.Tolgie_doppio_ident(Primo:Integer;Ident : String);
var c1,c2 : integer;
    testo,testo2 : String;
Begin
  Ident := UpperCase(Corregge_Ident(Ident));
  c1 := Primo;
  While (c1<=txt.Count - 1) do
  begin
    testo2 := Trim(Uppercase(txt[c1]));
    if (testo2<>'') then
    begin
      if (testo2[1]='[') then exit; // Inizia una nuovs sezione, quindi esce
      c2 := pos('=',txt[c1]);
      if (c2>0) then
      begin
        testo := Copy(testo2,1,c2-1);
        if (Testo=Ident) then
        begin
          txt.Delete(c1);
        end
        else c1 := c1 + 1;
      end
      else c1 := c1 + 1;
    end
    else c1 := c1 + 1;
  end;
End;

(******************************************************************************
 *                                                                            *
 ******************************************************************************)
Procedure TACIniFiles.WriteString(Section, Ident, Value: string);
var c1 : integer;
Begin
  Ident := Corregge_Ident(Ident);
  txt := nil;
  Try
    Txt := TStringList.Create;
    if (FileExists(FileName)) then
      Txt.LoadFromFile(FileName)
    else
      Txt.Clear;
    c1 := Cerca_sezione(Section);

    if (c1<0) then // Sezione nuova
    begin
      txt.add(Completa_nome_sezione(Trim(Section)));
      txt.add(Ident+'='+Value);
    end
    else
    begin // Sezione esistente
      txt.Insert(c1+1,Ident+'='+Value);
      Tolgie_doppio_ident(c1+2,Ident);
    end;
    Txt.SaveToFile(FileName)
  Finally
    if (txt<>nil) then Txt.Free;
  end;
End;

(******************************************************************************
 *                                                                            *
 ******************************************************************************)
function TACIniFiles.cerca_ident(Sezione,Ident:String):integer;
var c1, c2 : integer;
    testo, testo2 : String;
Begin
  Ident := UpperCase(Corregge_Ident(Ident));
  c1 := Cerca_Sezione(Sezione);
  if (c1>=0) then
  Begin
    c1 := c1 + 1; // Passa al prossimo
    While(c1<=txt.Count - 1) do
    begin

      testo := Trim(txt[c1]);
      if (testo[1]='[') then break; // Nuova sezione, fine della ricerca
      c2 := pos('=',testo);
      if (c2>0) then
      begin
        testo2 := copy(testo,1,c2-1);
        testo2 := uppercase(trim(testo2));
        if(testo2=Ident) then // Valore ritrovato
        begin
          cerca_ident := c1;
          exit;
        end;
      end;
      c1 := c1 + 1; // Passa al prossimo
    end;
  End;
  cerca_ident:=-1;

End;
(******************************************************************************
 *                                                                            *
 ******************************************************************************)
Function TACIniFiles.ReadString(Section, Ident, DefaultValue: string):String;
var c1 : integer;
    testo : String;
Begin
  testo := DefaultValue;
  txt := Nil;
  Try
    Txt := TStringList.Create;
    if (FileExists(FileName)) then
      Txt.LoadFromFile(FileName)
    else
      Txt.Clear;

    c1 := cerca_ident(Section,Ident);
    if(c1>=0) then
    begin
      testo := txt[c1];
      c1 := pos('=',testo);
      if (C1>0) then
      begin
        testo := Trim(copy(testo,c1+1,length(testo)-c1));
      end;

    end;
    ReadString := testo;
  Finally
    txt.Free; 
  end;

End;


(******************************************************************************
 *                                                                            *
 ******************************************************************************)
Procedure TACIniFiles.WriteInteger(Section, Ident:String; Value: Integer);
Begin
 WriteString(Section,Ident,IntToStr(Value));
End;

(******************************************************************************
 *                                                                            *
 ******************************************************************************)
Function TACIniFiles.ReadInteger(Section, Ident:String; DefaultValue: Integer):Integer;
var fl : Integer;
    app1 : String;
    c1   : Integer;
Begin
  app1 := IntToStr(DefaultValue);
  app1 := ReadString(Section,Ident,app1);
  val(app1, c1, fl);
  if (fl<>0) then c1 := DefaultValue;
  ReadInteger := c1;
End;

end.
