(******************************************************************************
 * ACFileType                                                                 *
 ******************************************************************************)
unit ACFileType;
{$i AcDefinizioni.pas }
(******************************************************************************
 * Interface                                                                  *
 ******************************************************************************)
interface

(******************************************************************************
 * Uses                                                                       *
 ******************************************************************************)
uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ACRegistry, Registry
{$IFDEF DELPHI2}
   ,DsgnIntf
{$ENDIF}
{$IFDEF DELPHI6}
   ,DesignIntf,DesignEditors
{$ENDIF};


(******************************************************************************
 * TACFileType                                                                *
 ******************************************************************************)
type
  TACFileType = class(TComponent)
  private
    { Private declarations }
    F_Ext          : String;
    F_desc         : String;
    F_OpenProgram  : String;
    F_InternalName : String;

    ACReg : TACRegistryString;
  protected
    { Protected declarations }
    procedure Set_Ext(txt:String);
    procedure Set_Desc(txt:String);
    Procedure Set_OpenProgram(txt:string);

//    Procedure Set_InternalName(txt:string);

  public
    { Public declarations }
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
  published
    { Published declarations }
    Property InternalName : String read F_InternalName Write F_InternalName;
    property Ext : String Read F_Ext Write set_ext;
    Property Description  : String read F_Desc write Set_Desc;
    Property OpenProgram  : String Read F_OpenProgram Write Set_OpenProgram;

  end;
(******************************************************************************
 * TAcFileTypeEditProperty                                                    *
 ******************************************************************************)
type TAcFileTypeEditProperty = Class(TStringProperty)
 public
   function GetAttributes : TPropertyAttributes; override;
   procedure GetValues(Proc: TGetStrProc);override;
 end;


(******************************************************************************
 * Implementationg                                                            *
 ******************************************************************************)
implementation


(******************************************************************************
 * Set_Ext                                                                    *
 ******************************************************************************)
procedure TACFileType.Set_Ext(txt:String);
Var Txt1 : String;

begin
  F_Ext := Txt;
  if(txt<>'') then
  begin
    AcReg.KeyName := Ext;
    Txt1 := AcReg.StrValue;
    if(txt1<>'') then
    begin
      InternalName := txt1;
      AcReg.KeyName := Txt1;
      F_Desc := AcReg.StrValue;
      AcReg.KeyName := Txt1+'\shell\open\command';
      F_OpenProgram := AcReg.StrValue;
    end
    Else
    begin
      InternalName := '';
      AcReg.KeyName := '';
      F_Desc := '';
      F_OpenProgram := '';

    end

  end;

End;

(******************************************************************************
 * Constructor                                                                *
 ******************************************************************************)
constructor TACFileType.Create(AOwner: TComponent);
Begin
 inherited;
 ACReg := TACRegistryString.Create(Self);
 ACReg.Root := HKEY_CLASSES_ROOT;
 Ext := '';
 F_Desc := '';

End;

(******************************************************************************
 * Destructor                                                                 *
 ******************************************************************************)
destructor TACFileType.Destroy;
Begin
 ACReg.Free;
 Inherited;
End;

(******************************************************************************
 * Set_Desc                                                                   *
 ******************************************************************************)
procedure TACFileType.Set_Desc(txt:String);
Var Txt1 : String;
begin
  if (Ext<>'') then
  begin
    F_Desc := Txt;
    AcReg.KeyName := Ext;
    Txt1 := AcReg.StrValue;
    if(Txt1='') then // Se l'estensione non esiste la crea
    begin
      AcReg.KeyName := Ext;
      AcReg.StrValue:=InternalName;
      Txt1:=InternalName;
    end;
    if(txt1<>'') then
    begin
      AcReg.KeyName := Txt1;
      AcReg.StrValue:=Description;
    End;
  End;

End;

(******************************************************************************
 * Set_OpenProgram                                                            *
 ******************************************************************************)
procedure TACFileType.Set_OpenProgram(txt:String);
Var Txt1 : String;
begin
  if (Ext<>'') then
  begin
    F_OpenProgram := Txt;
    AcReg.KeyName := Ext;
    Txt1 := AcReg.StrValue;
    if(Txt1='') then // Se l'estensione non esiste la crea
    begin
      AcReg.KeyName := Ext;
      AcReg.StrValue:=InternalName;
      Txt1:=InternalName;
    end;
    if(txt1<>'') then
    begin
      AcReg.KeyName := Txt1+'\shell\open\command';
      AcReg.StrValue:=OpenProgram;
    End;
  End;

End;


(******************************************************************************
 * Edit                                                                       *
 ******************************************************************************)
//procedure TAcKeyEditProperty.Edit;
procedure TAcFileTypeEditProperty.GetValues(Proc: TGetStrProc);
Var
//    IntRoot : Integer;
    List    : TStringList;
    Treg    : TRegistry;
    c1      : Integer;
//    base    : String;
begin
  List := Nil;
  TReg := Nil;
  try
    list := TStringList.Create;
    treg := TRegistry.create;
    TReg.RootKey:=$80000000; //HKEY_CLASSES_ROOT;
    Treg.openkey('',false);

    TReg.GetKeyNames(List);
    for c1 := 0 to List.count-1 do
      if (List.Strings[c1][1]='.') then
        proc(List.Strings[c1]);
  finally
    if (List<>Nil) then list.free;
    if (Treg<>Nil) then TReg.Free;
  end;
end;

(******************************************************************************
 * GetAttributes                                                              *
 ******************************************************************************)
function TAcFileTypeEditProperty.GetAttributes : TPropertyAttributes;
begin
  Result:=inherited GetAttributes+[paValueList, paDialog, paMultiSelect, paAutoUpdate, paSortList];
end;



end.
